package javax.xml.crypto.dom;

import java.util.Collections;
import java.util.Iterator;
import java.net.URI;
import javax.xml.crypto.URIDereferencer;
import javax.xml.crypto.KeySelector;
import org.w3c.dom.Element;
import java.util.HashMap;
import javax.xml.crypto.XMLCryptoContext;

public class DOMCryptoContext implements XMLCryptoContext
{
    private HashMap<String, String> nsMap;
    private HashMap<String, Element> idMap;
    private HashMap<Object, Object> objMap;
    private String baseURI;
    private KeySelector ks;
    private URIDereferencer dereferencer;
    private HashMap<String, Object> propMap;
    private String defaultPrefix;
    
    protected DOMCryptoContext() {
        this.nsMap = new HashMap();
        this.idMap = new HashMap();
        this.objMap = new HashMap();
        this.propMap = new HashMap();
    }
    
    @Override
    public String getNamespacePrefix(String key, String s) {
        if (key == null) {
            throw new NullPointerException("namespaceURI cannot be null");
        }
        String s2 = (String)this.nsMap.get(key);
        return (s2 != null) ? s2 : s;
    }
    
    @Override
    public String putNamespacePrefix(String key, String value) {
        if (key == null) {
            throw new NullPointerException("namespaceURI is null");
        }
        return (String)this.nsMap.put(key, value);
    }
    
    @Override
    public String getDefaultNamespacePrefix() {
        return this.defaultPrefix;
    }
    
    @Override
    public void setDefaultNamespacePrefix(String defaultPrefix) {
        this.defaultPrefix = defaultPrefix;
    }
    
    @Override
    public String getBaseURI() {
        return this.baseURI;
    }
    
    @Override
    public void setBaseURI(String s) {
        if (s != null) {
            URI.create(s);
        }
        this.baseURI = s;
    }
    
    @Override
    public URIDereferencer getURIDereferencer() {
        return this.dereferencer;
    }
    
    @Override
    public void setURIDereferencer(URIDereferencer dereferencer) {
        this.dereferencer = dereferencer;
    }
    
    @Override
    public Object getProperty(String key) {
        if (key == null) {
            throw new NullPointerException("name is null");
        }
        return this.propMap.get(key);
    }
    
    @Override
    public Object setProperty(String key, Object value) {
        if (key == null) {
            throw new NullPointerException("name is null");
        }
        return this.propMap.put(key, value);
    }
    
    @Override
    public KeySelector getKeySelector() {
        return this.ks;
    }
    
    @Override
    public void setKeySelector(KeySelector ks) {
        this.ks = ks;
    }
    
    public Element getElementById(String key) {
        if (key == null) {
            throw new NullPointerException("idValue is null");
        }
        return (Element)this.idMap.get(key);
    }
    
    public void setIdAttributeNS(Element value, String s, String str) {
        if (value == null) {
            throw new NullPointerException("element is null");
        }
        if (str == null) {
            throw new NullPointerException("localName is null");
        }
        String attributeNS = value.getAttributeNS(s, str);
        if (attributeNS == null || attributeNS.length() == 0) {
            throw new IllegalArgumentException(str + " is not an attribute");
        }
        this.idMap.put(attributeNS, value);
        return;
    }
    
    public Iterator iterator() {
        return Collections.unmodifiableMap(this.idMap).entrySet().iterator();
    }
    
    @Override
    public Object get(Object key) {
        return this.objMap.get(key);
    }
    
    @Override
    public Object put(Object key, Object value) {
        return this.objMap.put(key, value);
    }
}
